@@ -40,10 +40,15 @@ try:
 except ImportError:
     from pystan.external.scipy import mquantiles
 
+import pystan.chains as chains
 from pystan.constants import MAX_UINT
 
+logger = logging.getLogger('pystan')
+logger.setLevel(logging.INFO)
+
+
 def _print_stanfit(fit, pars=None, probs=(0.025, 0.25, 0.5, 0.75, 0.975),
-                  digits_summary=1):
+                   digits_summary=1):
         if fit.mode == 1:
             return "Stan model '{}' is of mode 'test_grad';\n"\
                    "sampling is not conducted.".format(fit.model_name)
@@ -73,7 +78,7 @@ def _print_stanfit(fit, pars=None, probs=(0.025, 0.25, 0.5, 0.75, 0.975),
         footer = footer.format(sampler, date)
         s = _summary(fit, pars, probs)
         body = _array_to_table(s['summary'], s['summary_rownames'],
-                                 s['summary_colnames'], digits_summary)
+                               s['summary_colnames'], digits_summary)
         return header + body + footer
 
 
@@ -90,14 +95,16 @@ def _array_to_table(arr, rownames, colnames, n_digits):
     """
     assert arr.shape == (len(rownames), len(colnames))
     rownames_maxwidth = max(len(n) for n in rownames)
-    widths = [rownames_maxwidth + 1] + [max(5, len(n) + 1) for n in colnames]
+    widths = [rownames_maxwidth] + [max(5, len(n) + 1) for n in colnames]
     header = '{:>{width}}'.format('', width=widths[0])
     for name, width in zip(colnames, widths[1:]):
         header += '{name:>{width}}'.format(name=name, width=width)
     lines = [header]
     for rowname, row in zip(rownames, arr):
         line = '{name:{width}}'.format(name=rowname, width=widths[0])
-        for num, width in zip(row, widths[1:]):
+        for j, (num, width) in enumerate(zip(row, widths[1:])):
+            if colnames[j] == 'n_eff':
+                num = int(round(num, 0))
             line += '{num:{width}}'.format(num=round(num, n_digits), width=width)
         lines.append(line)
     return '\n'.join(lines)
@@ -147,9 +154,11 @@ def _summary(fit, pars=None, probs=(0.025, 0.25, 0.5, 0.75, 0.975), **kwargs):
 
     ss = _summary_sim(fit.sim, pars, probs)
     # TODO: include sem, ess and rhat: ss['ess'], ss['rhat']
-    s1 = np.column_stack([ss['msd'][:, 0], ss['msd'][:, 1], ss['quan']])
+    s1 = np.column_stack([ss['msd'][:, 0], ss['sem'], ss['msd'][:, 1], ss['quan'], ss['ess'], ss['rhat']])
     s1_rownames = ss['c_msd_names']['parameters']
-    s1_colnames = ss['c_msd_names']['stats'] + ss['c_quan_names']['stats']
+    s1_colnames = (ss['c_msd_names']['stats'][0],) + ('se_mean',) + \
+            (ss['c_msd_names']['stats'][1],) + ss['c_quan_names']['stats'] + \
+            ('n_eff', 'Rhat')
     s2 = _combine_msd_quan(ss['c_msd'], ss['c_quan'])
     s2_rownames = ss['c_msd_names']['parameters']
     s2_colnames = ss['c_msd_names']['stats'] + ss['c_quan_names']['stats']
@@ -177,7 +186,6 @@ def _combine_msd_quan(msd, quan):
     dim1 = msd.shape
     dim2 = quan.shape
     n_par, _, n_chains = dim1
-    n_stat = dim1[1] + dim2[1]
     ll = []
     for i in range(n_chains):
         a1 = msd[:, :, i]
@@ -256,11 +264,11 @@ def _summary_sim(sim, pars, probs):
                         stats=probs_str,
                         chains=tuple("chain:{}".format(cid) for cid in cids))
     # TODO: include sem, ess and rhat, see rstan/rstan/src/chains.cpp
-    # ess = np.array([chains.effective_sample_size(sim, n) for n in tidx_colm])
-    # rhat = np.array([chains.split_potential_scale_reduction(sim, n) for n in tidx_colm])
+    ess = np.array([chains.ess(sim, n) for n in tidx_colm], dtype=int)
+    rhat = np.array([chains.splitrhat(sim, n) for n in tidx_colm])
     return dict(msd=msd, c_msd=c_msd, c_msd_names=c_msd_names, quan=quan,
                 c_quan=c_quan, c_quan_names=c_quan_names,
-                # sem=msd[:, 2] / np.sqrt(ess), ess=ess, rhat=rhat,
+                sem=msd[:, 1] / np.sqrt(ess), ess=ess, rhat=rhat,
                 row_major_idx=tidx_rowm, col_major_idx=tidx_colm)
 
 
@@ -468,14 +476,14 @@ def _check_seed(seed, raise_exception=True):
             if raise_exception is True:
                 raise ValueError("`seed` must be a string of digits.")
             else:
-                logging.warn("`seed` needs to be a string of digits.")
+                logger.warn("`seed` needs to be a string of digits.")
                 return None
     elif isinstance(seed, Number):
         seed = int(seed)
     elif seed is None:
         seed = random.randint(0, MAX_UINT)
     else:
-        logging.warn('`seed` did not have expected characteristics.')
+        logger.warn('`seed` did not have expected characteristics.')
 
     return seed
 
@@ -766,5 +774,5 @@ def _writable_sample_file(file, warn=True, wfun=None):
     else:
         dir2 = tempfile.mkdtemp()
         if warn:
-            logging.warning(wfun(dir, dir2))
+            logger.warning(wfun(dir, dir2))
         return os.path.join(dir2, os.path.basename(file))
