@@ -16,6 +16,7 @@ else:
 import datetime
 import importlib
 import imp
+import io
 import logging
 from numbers import Number
 import os
@@ -36,6 +37,10 @@ import pystan.api
 from pystan.constants import MAX_UINT
 import pystan.misc
 
+logger = logging.getLogger('pystan')
+logger.setLevel(logging.INFO)
+
+
 def load_module(module_name, module_path):
     """Load the module named `module_name` from  `module_path`
     independently of the Python version."""
@@ -196,12 +201,12 @@ class StanModel:
         self.save_dso = save_dso
 
         msg = "COMPILING THE C++ CODE FOR MODEL {} NOW."
-        logging.warning(msg.format(self.model_name))
+        logger.warning(msg.format(self.model_name))
         if verbose:
             msg = "OS: {}, Python: {}, Cython {}".format(sys.platform,
                                                          sys.version,
                                                          Cython.__version__)
-            logging.info(msg)
+            logger.info(msg)
         if boost_lib is not None:
             # FIXME: allow boost_lib, eigen_lib to be specified
             raise NotImplementedError
@@ -228,15 +233,15 @@ class StanModel:
             os.makedirs(lib_dir)
 
         model_cpp_file = os.path.join(lib_dir, self.model_cppname + '.hpp')
-        with open(model_cpp_file, 'w') as outfile:
+        with io.open(model_cpp_file, 'w') as outfile:
             outfile.write(self.model_cppcode)
 
         pyx_file = os.path.join(lib_dir, module_name + '.pyx')
         pyx_template_file = os.path.join(pystan_dir, 'stanfit4model.pyx')
-        with open(pyx_template_file) as infile:
+        with io.open(pyx_template_file, 'r', encoding='utf-8') as infile:
             s = infile.read()
             template = string.Template(s)
-        with open(pyx_file, 'w') as outfile:
+        with io.open(pyx_file, 'w') as outfile:
             s = template.safe_substitute(model_cppname=self.model_cppname)
             outfile.write(s)
 
@@ -300,7 +305,7 @@ class StanModel:
             module_filename = state['module'].__file__
             state['module_filename'] = module_filename
             state['module_name'] = state['module'].__name__
-            with open(module_filename, 'rb') as f:
+            with io.open(module_filename, 'rb') as f:
                 state['module_bytes'] = f.read()
         del state['module']
         del state['fit_class']
@@ -322,15 +327,15 @@ class StanModel:
             if not os.path.exists(lib_dir):
                 os.makedirs(lib_dir)
             module_basename = os.path.basename(module_filename)
-            with open(os.path.join(lib_dir, module_basename), 'wb') as f:
+            with io.open(os.path.join(lib_dir, module_basename), 'wb') as f:
                 f.write(module_bytes)
             try:
                 self.module = load_module(module_name, lib_dir)
                 self.fit_class = getattr(self.module, "StanFit4" + self.model_cppname)
             except Exception as e:
-                logging.warning(e)
-                logging.warning("Something went wrong while unpickling "
-                                "the StanModel. Consider recompiling.")
+                logger.warning(e)
+                logger.warning("Something went wrong while unpickling "
+                               "the StanModel. Consider recompiling.")
 
     def optimizing(self, data=None, seed=None,
                    init='random', sample_file=None, method="Newton",
@@ -606,7 +611,7 @@ class StanModel:
             if kwargs.get('refresh') is None or kwargs.get('refresh') > 0:
                 chain_num = i + 1
                 msg = "{} FOR MODEL {} NOW (CHAIN {})."
-                logging.info(msg.format(mode, self.model_name, chain_num))
+                logger.info(msg.format(mode, self.model_name, chain_num))
             ret, samples_i = fit._call_sampler(args_list[i])
             samples.append(samples_i)
             # call_sampler in stan_fit.hpp will raise a std::runtime_error
